package builder

import (
	"fmt"
)

var MinGW = Library{
	name:      "mingw-w64",
	sourceDir: func() string { return "" }, // unused
	cflags: func(target, headerPath string) []string {
		// No flags necessary because there are no files to compile.
		return nil
	},
	librarySources: func(target string) []string {
		// We only use the UCRT DLL file. No source files necessary.
		return nil
	},
}

// makeMinGWExtraLibs returns a slice of jobs to import the correct .dll
// libraries. This is done by converting input .def files to .lib files which
// can then be linked as usual.
//
// TODO: cache the result. At the moment, it costs a few hundred milliseconds to
// compile these files.
func makeMinGWExtraLibs(tmpdir string) []*compileJob {
	var jobs []*compileJob
	for _, name := range []string{"kernel32", "ucrt"} {
		outpath := fmt.Sprintf("/usr/x86_64-w64-mingw32/sys-root/mingw/lib/lib%s.a", name)
		job := checkIfPackagedFileExistsJob(outpath, "mingw64-crt and mingw64-headers")
		jobs = append(jobs, job)
	}
	return jobs
}
